import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import "../dateutils.js" as DateUtils
import "../databasemodule_v2.js" as DB

UbuntuShape
{
    id: articleFullImg
    width: units.gu(24)
    height: units.gu(20)
    radius: "medium"
    color: rss_item.status == "1" ? Qt.rgba(0, 0, 0, 0.7) : Qt.rgba(0, 0, 0, 0.4)

    property variant rss_item
    property variant imageArray: []
    property variant rss_model
    property int model_index

    Item {
        id: shapeClipper
        width: parent.width
        height: parent.height / 2
        clip: true

        UbuntuShape {
            id: u_pic
            width: parent.width
            height: pic.height > (articleFullImg.height - units.gu(1.5)) ? (articleFullImg.height - units.gu(1.5)) : pic.height
            radius: "medium"
            image: Image {
                id: pic
                width: {
                    if (implicitHeight < 50 || implicitWidth < 50) return 0
                    else return u_pic.width
                }
                height: width * implicitHeight / implicitWidth
                source: imageArray[0]
                sourceSize.width: u_pic.width
            }
        }
    }

    Column
    {
        id: content
        anchors.top: shapeClipper.bottom
        anchors.bottom: parent.bottom
        anchors.bottomMargin: units.gu(1.5)
        anchors.horizontalCenter: parent.horizontalCenter
        width: parent.width - units.gu(2)
//        height: parent.height / 2.3
        spacing: units.gu(0.8)

        Label
        {
            id: label_time
            text: DateUtils.formatRelativeTime(i18n, rss_item.pubdate)
            fontSize: "x-small"
            width: parent.width
            wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            opacity: 0.6
        }

        Label
        {
            id: label_title
            text: rss_item.title
            width: parent.width
            height: parent.height - parent.spacing * 2 - label_time.paintedHeight - label_feedname.paintedHeight
            wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            fontSize: "small"
            textFormat: Text.PlainText
            font.weight: Font.DemiBold
            elide: Text.ElideRight
            opacity: rss_item.status == "1" ? 0.4 : 0.8
        }

        Label
        {
            id: label_feedname
            text: rss_item.feed_name
            fontSize: "x-small"
            width: parent.width
            wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            opacity: 0.6
        }
    }

    MouseArea
    {
        anchors.fill: parent

        onClicked:
        {
//            console.log(JSON.stringify(rss_item))
//            var dbResult = DB.updateArticleStatus(rss_item.id, "1")
//            if (dbResult.rowsAffected == 1) {
//                rss_item.status = "1"
//            }
            mainView.toRssPage(rss_model, model_index)
        }
    }
}
